@@ -8,22 +8,22 @@
 
 #include <CalendarSupport/Utils>
 
-#include <KCalendarCore/Incidence>
 #include <KCalendarCore/FileStorage>
+#include <KCalendarCore/Incidence>
 
 #include <AkonadiCore/CollectionFetchJob>
 #include <AkonadiCore/CollectionFetchScope>
 #include <AkonadiCore/ItemFetchJob>
 #include <AkonadiCore/ItemFetchScope>
 
-#include <KLocalizedString>
 #include <KJob>
+#include <KLocalizedString>
 #include <QDebug>
 #include <QTimeZone>
 
 #include <QCoreApplication>
 
-static void print(const QString &message)
+static void printOut(const QString &message)
 {
     QTextStream out(stdout);
     out << message << "\n";
@@ -32,9 +32,11 @@ static void print(const QString &message)
 void Backuper::emitFinished(bool success, const QString &message)
 {
     if (success) {
-        print(QLatin1Char('\n') + i18np("Backup was successful. %1 incidence was saved.", "Backup was successful. %1 incidences were saved.", m_calendar->incidences().count()));
+        printOut(
+            QLatin1Char('\n')
+            + i18np("Backup was successful. %1 incidence was saved.", "Backup was successful. %1 incidences were saved.", m_calendar->incidences().count()));
     } else {
-        print(message);
+        printOut(message);
     }
 
     m_calendar.clear();
@@ -43,7 +45,8 @@ void Backuper::emitFinished(bool success, const QString &message)
     qApp->exit(success ? 0 : -1); // TODO: If we move this class to kdepimlibs, remove this
 }
 
-Backuper::Backuper(QObject *parent) : QObject(parent)
+Backuper::Backuper(QObject *parent)
+    : QObject(parent)
     , m_backupInProgress(false)
 {
 }
@@ -59,14 +62,13 @@ void Backuper::backup(const QString &filename, const QList<Akonadi::Collection::
         emitFinished(false, i18n("A backup is already in progress."));
         return;
     }
-    print(i18n("Backing up your calendar data..."));
+    printOut(i18n("Backing up your calendar data..."));
     m_calendar = KCalendarCore::MemoryCalendar::Ptr(new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
     m_requestedCollectionIds = collectionIds;
     m_backupInProgress = true;
     m_filename = filename;
 
-    Akonadi::CollectionFetchJob *job = new Akonadi::CollectionFetchJob(Akonadi::Collection::root(),
-                                                                       Akonadi::CollectionFetchJob::Recursive);
+    Akonadi::CollectionFetchJob *job = new Akonadi::CollectionFetchJob(Akonadi::Collection::root(), Akonadi::CollectionFetchJob::Recursive);
 
     job->fetchScope().setContentMimeTypes(KCalendarCore::Incidence::mimeTypes());
     connect(job, &Akonadi::CollectionFetchJob::result, this, &Backuper::onCollectionsFetched);
@@ -76,23 +78,16 @@ void Backuper::backup(const QString &filename, const QList<Akonadi::Collection::
 void Backuper::onCollectionsFetched(KJob *job)
 {
     if (job->error() == 0) {
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-        QSet<QString> mimeTypeSet = KCalendarCore::Incidence::mimeTypes().toSet();
-#else
         const QStringList mimetypes = KCalendarCore::Incidence::mimeTypes();
         QSet<QString> mimeTypeSet = QSet<QString>(mimetypes.begin(), mimetypes.end());
-#endif
         Akonadi::CollectionFetchJob *cfj = qobject_cast<Akonadi::CollectionFetchJob *>(job);
-        foreach (const Akonadi::Collection &collection, cfj->collections()) {
+        const auto collections = cfj->collections();
+        for (const Akonadi::Collection &collection : collections) {
             if (!m_requestedCollectionIds.isEmpty() && !m_requestedCollectionIds.contains(collection.id())) {
                 continue;
             }
             const QStringList contentMimeTypesLst = collection.contentMimeTypes();
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-            QSet<QString> collectionMimeTypeSet = contentMimeTypesLst.toSet();
-#else
             QSet<QString> collectionMimeTypeSet = QSet<QString>(contentMimeTypesLst.begin(), contentMimeTypesLst.end());
-#endif
             if (!mimeTypeSet.intersect(collectionMimeTypeSet).isEmpty()) {
                 m_collections << collection;
                 loadCollection(collection);
@@ -111,7 +106,7 @@ void Backuper::onCollectionsFetched(KJob *job)
 
 void Backuper::loadCollection(const Akonadi::Collection &collection)
 {
-    print(i18n("Processing collection %1 (id=%2)...", collection.displayName(), collection.id()));
+    printOut(i18n("Processing collection %1 (id=%2)...", collection.displayName(), collection.id()));
     Akonadi::ItemFetchJob *ifj = new Akonadi::ItemFetchJob(collection, this);
     ifj->setProperty("collectionId", collection.id());
     ifj->fetchScope().fetchFullPayload(true);
@@ -129,10 +124,10 @@ void Backuper::onCollectionLoaded(KJob *job)
         Akonadi::ItemFetchJob *ifj = qobject_cast<Akonadi::ItemFetchJob *>(job);
         Akonadi::Collection::Id id = ifj->property("collectionId").toInt();
         Q_ASSERT(id != -1);
-        Akonadi::Item::List items = ifj->items();
+        const Akonadi::Item::List items = ifj->items();
         m_pendingCollections.removeAll(id);
 
-        foreach (const Akonadi::Item &item, items) {
+        for (const Akonadi::Item &item : items) {
             KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
             Q_ASSERT(incidence);
             m_calendar->addIncidence(incidence);
